@@ -6,7 +6,7 @@ use 5.010000;
 use strict;
 use warnings;
 
-our $VERSION = '1.22';
+our $VERSION = '1.23';
 
 1;
 __END__
@@ -98,7 +98,7 @@ L<http://en.wikipedia.org/wiki/Forte_number>
 =item *
 
 L<Music::AtonalUtil>, L<Music::Chord::Positions>,
-L<Music::LilyPondUtil>, L<Music::Tension>
+L<Music::LilyPondUtil>, L<Music::Tension> and others.
 
 =back
 
@@ -110,8 +110,7 @@ thrig - Jeremy Mates (cpan:JMATES) C<< <jmates at cpan.org> >>
 
 Copyright (C) 2012-2015 by Jeremy Mates
 
-This library is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself, either Perl version 5.16 or, at
-your option, any later version of Perl 5 you may have available.
+This module is free software; you can redistribute it and/or modify it
+under the Artistic License (2.0).
 
 =cut
